# 🧪 funcnodes-chemprop

funcnodes-chemprop is a funcnodes module that integrates the Chemprop deep learning framework for molecular property prediction into node-based pipelines. It allows you to load molecular data, featurize molecules, train a Chemprop model, and predict properties — all in an interactive, no-code/low-code environment powered by [FuncNodes](https://github.com/Linkdlab/funcnodes).

## 🧑‍💻 Developer Notes

We currently face issues if you use this module on Mac with enabled Metal Performance Shaders, we hope to be able to resolve this soon.
